{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-25.05";
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    disko = {
      url = "github:nix-community/disko";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    nur.url = "github:nix-community/nur";
  };

  outputs = inputs @ { self, disko, nixpkgs, home-manager, ... }:
    let
      system = "x86_64-linux";
    in rec {
      mkSystem = {host, ...}: nixpkgs.lib.nixosSystem {
        inherit system;

          modules = [
            ./configuration.nix
	    ./options.nix
            ./pkgs
            host
            home-manager.nixosModules.home-manager
            disko.nixosModules.disko
            {
              home-manager.useGlobalPkgs = true; # Use global packages in home-manager
              home-manager.useUserPackages = true; # Use user packages in home-manager

              home-manager.extraSpecialArgs = {
                inherit inputs;
              };
            }
          ];

          specialArgs = {
            inherit inputs home-manager;
          };

          pkgs = import nixpkgs {
            inherit system;
            config.allowUnfree = true; # Allow unfree packages globally

            overlays = [
              inputs.nur.overlays.default
            ];
          };
      };

      nixosConfigurations = {
        vm = mkSystem {
          host = ./hosts/vm.nix;
        };
        laptop = mkSystem {
          host = ./hosts/laptop;
        };
      };
    };
}
